@@ -6,8 +6,8 @@ but already implemented in YaDraw methods automatically account for shifts and s
 import pygame
 import unittest
 
-from yadraw import logging_config
-import yadraw as yd
+from yatools import logging_config
+import yadraw.yadraw as yd
 import time
 
 logging_config.init()
